# coding: utf-8

"""
    PSI AWS Wrangler

    Module containing a wrapper class for AWS Wrangler.   # noqa: E501
"""

from setuptools import setup, find_packages  # noqa: H301

NAME = "psi_awswrangler"
VERSION = "0.2.6"
REQUIRES = [
    'awswrangler==2.15.1',
    'boto3>=1.20.47',
    'typeguard==2.13.3',
    'python-utils==3.6.0'

]

# To install the library, run the following
#
# python setup.py install
#
# prerequisite: setuptools
# http://pypi.python.org/pypi/setuptools

setup(
    name=NAME,
    version=VERSION,
    description="PSI AWS Wrangler",
    author="Pearson Service Insights",
    author_email="TOIOServiceWorkflowAutomation@grp.pearson.com",
    url="https://gitlab.com/pearson-io-swa/integrations",
    keywords=["Pearson", "PSI", "PSI AWS Wrangler", "AWS", "Wrangler"],
    install_requires=REQUIRES,
    packages=find_packages(),
    include_package_data=True,
    long_description="""\
     Module containing a wrapper class for AWS Wrangler.   # noqa: E501
    """,
)
